'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.required = required;
exports.validarMaximo = validarMaximo;
exports.validarMaximoInclusive = validarMaximoInclusive;
exports.onlyNumber = onlyNumber;
exports.onlyEnteros = onlyEnteros;
exports.menorQue = menorQue;
exports.menorQueInclusive = menorQueInclusive;
exports.mayorQue = mayorQue;
exports.mayorQueInclusive = mayorQueInclusive;
exports.maxLength = maxLength;
exports.minLength = minLength;
exports.isEmail = isEmail;
// function isInt(n){
//     return Number(n) === n && n % 1 === 0;
// }

function isFloat(n) {
  return Number(n) === n && n % 1 !== 0;
}

function required(value) {
  return value === undefined || value === '' ? 'Requerido' : null;
}

function validarMaximo(maximo, minimo) {
  if (maximo !== undefined && maximo !== '' && (Number(maximo) || maximo === 0) && minimo !== undefined && minimo !== '' && (Number(minimo) || minimo === 0) && Number(maximo) < Number(minimo)) {
    return 'El máximo debe ser mayor o igual al mínimo';
  } else {
    return null;
  }
}

function validarMaximoInclusive(maximo, minimo) {
  if (maximo !== undefined && maximo !== '' && (Number(maximo) || maximo === 0) && minimo !== undefined && minimo !== '' && (Number(minimo) || minimo === 0) && Number(maximo) <= Number(minimo)) {
    return 'El máximo debe ser mayor al mínimo';
  } else {
    return null;
  }
}

function onlyNumber(value) {
  if (value !== undefined && value !== '' && isNaN(Number(value))) {
    return 'Solo números';
  } else {
    return null;
  }
}

function onlyEnteros(value) {
  if (value !== undefined && value !== '' && isFloat(Number(value))) {
    return 'Solo enteros';
  } else {
    return null;
  }
}

function menorQue(value, parametro) {
  if (value !== undefined && value !== '' && (Number(value) || value === 0) && parametro !== undefined && parametro !== '' && (Number(parametro) || parametro === 0) && Number(value) >= Number(parametro)) {
    return 'Debe ser menor que ' + parametro;
  } else {
    return null;
  }
}

function menorQueInclusive(value, parametro) {
  if (value !== undefined && value !== '' && (Number(value) || value === 0) && parametro !== undefined && parametro !== '' && (Number(parametro) || parametro === 0) && Number(value) > Number(parametro)) {
    return 'Debe ser menor que o igual a ' + parametro;
  } else {
    return null;
  }
}

function mayorQue(value, parametro) {
  if (value !== undefined && value !== '' && (Number(value) || value === 0) && parametro !== undefined && parametro !== '' && (Number(parametro) || parametro === 0) && Number(value) <= Number(parametro)) {
    return 'Debe ser mayor que ' + parametro;
  } else {
    return null;
  }
}

function mayorQueInclusive(value, parametro) {
  if (value !== undefined && value !== '' && (Number(value) || value === 0) && parametro !== undefined && parametro !== '' && (Number(parametro) || parametro === 0) && Number(value) < Number(parametro)) {
    return 'Debe ser mayor que o igual a ' + parametro;
  } else {
    return null;
  }
}

function maxLength(value, parametro) {
  if (value !== undefined && value !== '') {
    var primerBlanco = /^ /;
    var ultimoBlanco = / $/;
    var variosBlancos = /[ ]+/g;
    value = value.toString();
    value = value.replace(variosBlancos, ' ');
    value = value.replace(primerBlanco, '');
    value = value.replace(ultimoBlanco, '');
    if (value.length > parametro) {
      return 'El máximo es de ' + parametro + ' caracteres';
    } else {
      return null;
    }
  } else {
    return null;
  }
}

function minLength(value, parametro) {
  if (value !== undefined && value !== '') {
    var primerBlanco = /^ /;
    var ultimoBlanco = / $/;
    var variosBlancos = /[ ]+/g;
    value = value.toString();
    value = value.replace(variosBlancos, ' ');
    value = value.replace(primerBlanco, '');
    value = value.replace(ultimoBlanco, '');
    if (value.length < parametro) {
      return 'El mínimo es de ' + parametro + ' caracteres';
    } else {
      return null;
    }
  } else {
    return null;
  }
}

function isEmail(value) {
  if (value !== undefined && value !== '' && !/^[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z]{2,4}$/i.test(value)) {
    return 'Email incorrecto';
  } else {
    return null;
  }
}

exports.default = {
  required: required,
  validarMaximo: validarMaximo,
  validarMaximoInclusive: validarMaximoInclusive,
  onlyNumber: onlyNumber,
  onlyEnteros: onlyEnteros,
  menorQue: menorQue,
  menorQueInclusive: menorQueInclusive,
  mayorQue: mayorQue,
  mayorQueInclusive: mayorQueInclusive,
  maxLength: maxLength,
  minLength: minLength,
  isEmail: isEmail
};